@@ -21,9 +21,9 @@ def get_partition(value, partitions):
     mid_element = int(len(limits)/2)
     while len(positions) > 1:
         if value >= limits[mid_element]:
-            positions = positions[mid_element:]
+            positions = positions[int(len(positions)/2):]
         else:
-            positions = positions[:mid_element]
+            positions = positions[:int(len(positions)/2)]
         mid_element = positions[int(len(positions)/2)]
     assert(len(positions) == 1)
     return positions[0]
@@ -35,4 +35,10 @@ def get_partitions(observation, partitions):
 
 def are_in_same_partition(obs1, obs2, partitions):
     assert(len(obs1) == len(obs2))
-    return np.all((abs(get_partitions(obs1, partitions) - get_partitions(obs2, partitions)) == 0))
+    are_same_partition(get_partitions(obs1, partitions),
+                       get_partitions(obs2, partitions))
+
+
+def are_same_partition(partition1, partition2):
+    assert(len(partition1) == len(partition2))
+    return np.all((abs(partition1 - partition2) == 0))
